Integrating with Django Reversion — Django Stories 1.0 documentation

Django Stories 1.0 documentation

# Integrating with Django Reversion

- Table of Contents
- index
  modules
  next
  previous

# Integrating with Django Reversion

1. Install django-reversion

   >     $ pip install django-reversion

2. Add `reversion` to your `INSTALLED_APPS` setting.

   >     INSTALLED_APPS = (
   >         ...
   >         'reversion',
   >         ...
   >     )

3. `./manage.py syncdb`

4. Set story settings

   >     STORY_SETTINGS['USE_REVERSION'] = True

Versions are tracked from when reversion is first installed.